Struct rust_sbml::Unit [−][src]
pub struct Unit {
pub kind: UnitSIdRef,
pub exponent: f64,
pub scale: i64,
pub multiplier: f64,
}A Unit object represents a reference to a (possibly transformed) base unit (see UnitSIdRef).
The attribute kind indicates the base unit, whereas the attributes exponent, scale and multiplier define how the base unit is being transformed.
Fields
kind: UnitSIdRefexponent: f64scale: i64multiplier: f64Trait Implementations
impl<'de> Deserialize<'de> for Unit[src]
impl<'de> Deserialize<'de> for Unit[src]fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>, [src]
__D: Deserializer<'de>,
impl StructuralPartialEq for Unit[src]
impl StructuralPartialEq for Unit[src]Auto Trait Implementations
impl RefUnwindSafe for Unit
impl RefUnwindSafe for Unitimpl UnwindSafe for Unit
impl UnwindSafe for UnitBlanket Implementations
impl<T> DeserializeOwned for T where
T: for<'de> Deserialize<'de>, [src]
impl<T> DeserializeOwned for T where
T: for<'de> Deserialize<'de>, [src]